package com.college.controller.auth

import com.auth0.jwt.JWT
import com.auth0.jwt.algorithms.Algorithm
import com.college.controller.request.UserRegistrationRequest
import com.college.controller.request.UserLoginRequest
import com.college.controller.response.AuthResponse
import com.college.domain.request.user.UserCreateRequest
import com.college.domain.request.user.UserFindRequest
import com.college.domain.usecase.UserUseCase
import io.ktor.http.*
import io.ktor.server.application.*
import io.ktor.server.request.*
import io.ktor.server.response.*
import io.ktor.server.routing.*
import org.koin.ktor.ext.inject
import java.util.*

fun Application.AuthRouter(){
    val userUseCase by inject<UserUseCase>()
    routing {
        route("auth"){
            val secret = environment.config.property("jwt.secret").getString()
            val issuer = environment.config.property("jwt.issuer").getString()
            post("login") {
                val user = call.receive<UserLoginRequest>()
                val findUser = userUseCase.getUserByLogin(userFindRequest = UserFindRequest(
                    login = user.login
                ))
                val token = JWT.create()
                    .withIssuer(issuer)
                    .withClaim("username", findUser.login)
                    .withExpiresAt(Date(System.currentTimeMillis() + 60000))
                    .sign(Algorithm.HMAC256(secret))
                call.respond(HttpStatusCode.OK, AuthResponse(jwtToken = token))
            }
            post("registration") {
                val newUser = call.receive<UserRegistrationRequest>()
                val userCreateRequest = UserCreateRequest(password = newUser.password, login = newUser.login, roleId = newUser.roleId)
                userUseCase.register(userCreateRequest)
            }
        }
    }
}